"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainApi = void 0;
class ChainApi {
    constructor(nodeos_url, contract, fetch) {
        this.nodeos_url = nodeos_url;
        this.contract = contract;
        this.fetch = fetch;
    }
    async getTableRows(payload) {
        return await this.fetch(`${this.nodeos_url}/v1/chain/get_table_rows`, {
            method: "POST",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify(payload),
        });
    }
    async getProposalByID(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "proposals",
            table_key: opts.id,
            lower_bound: opts.id,
            upper_bound: opts.id,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getProposalByContract(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "proposals",
            table_key: opts.contract,
            lower_bound: opts.contract,
            upper_bound: opts.contract,
            key_type: "name",
            index_position: "2",
        });
    }
    async getReward(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "rewards",
            table_key: opts.category,
            lower_bound: opts.category,
            upper_bound: opts.category,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getSlice(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "slice",
            table_key: opts.date,
            lower_bound: opts.date,
            upper_bound: opts.date,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getTopPool(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "toppools",
            table_key: opts.category,
            lower_bound: opts.category,
            upper_bound: opts.category,
            key_type: "i64",
            index_position: "1",
        });
    }
    async getVote(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: opts.proposal_id,
            table: "votes",
            table_key: opts.voter,
            lower_bound: opts.voter,
            upper_bound: opts.voter,
            key_type: "name",
            index_position: "1",
        });
    }
    async getContractWhiteList(opts) {
        return this.getTableRows({
            json: true,
            code: this.contract,
            scope: this.contract,
            table: "cntwhitelist",
            table_key: opts.account,
            lower_bound: opts.account,
            upper_bound: opts.account,
            key_type: "name",
            index_position: "1",
        });
    }
}
exports.ChainApi = ChainApi;
